==> graphql-compose-aws-3.0.0.tgz: package/lib/__tests__/AwsParam-test.js <==
"use strict";

var _graphqlCompose = require("graphql-compose");

var _graphql = require("graphql-compose/lib/graphql");

var _AwsParam = require("../AwsParam");

describe('AwsParam', () => {
  describe('static convertParam()', () => {
    it('scalars', () => {
      expect(_AwsParam.AwsParam.convertParam({
        type: 'boolean'
      }, '')).toBe('Boolean');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'string'
      }, '')).toBe('String');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'integer'
      }, '')).toBe('Int');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'float'
      }, '')).toBe('Float');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'timestamp'
      }, '')).toBe('Date');
      expect(_AwsParam.AwsParam.convertParam({}, '')).toBe('String');
    });
    it('map', () => {
      // it does not have keys, so should be JSON type
      expect(_AwsParam.AwsParam.convertParam({
        type: 'map',
        key: {},
        value: {}
      }, '')).toBe('JSON');
    });
    it('list', () => {
      const t = _AwsParam.AwsParam.convertParam({
        type: 'list',
        member: {},
        flattened: true
      }, '');

      expect(t).toEqual(['String']); // nested lists

      const t2 = _AwsParam.AwsParam.convertParam({
        type: 'list',
        member: {
          type: 'list',
          member: {}
        },
        flattened: true
      }, '');

      expect(t2).toEqual([['String']]);
    });
    it('structure', () => {
      const param = {
        type: 'structure',
        members: {
          Bucket: {}
        }
      };

      const t = _AwsParam.AwsParam.convertParam(param, 'Name');

      expect(t).toBeInstanceOf(_graphqlCompose.ObjectTypeComposer);

      const t2 = _AwsParam.AwsParam.convertParam(param, 'Name', true);

      expect(t2).toBeInstanceOf(_graphqlCompose.InputTypeComposer);
    });
    it('shape', () => {
      const shapesMock = {
        getInputShape: () => 'Int',
        getOutputShape: () => 'String'
      };

      const t = _AwsParam.AwsParam.convertParam({
        shape: 'Sk'
      }, 'Name', true, shapesMock);

      expect(t).toBe('Int');

      const t2 = _AwsParam.AwsParam.convertParam({
        shape: 'Sk'
      }, 'Name', false, shapesMock);

      expect(t2).toBe('String'); // as fallback use JSON, if shapes are empty

      const t3 = _AwsParam.AwsParam.convertParam({
        shape: 'Sk'
      }, 'Name');

      expect(t3).toBe('JSON');
    });
  });
  it('static convertInputStructure()', () => {
    const param = {
      type: 'structure',
      required: ['Bucket'],
      members: {
        Bucket: {
          location: 'uri',
          locationName: 'Bucket'
        },
        Delimiter: {
          location: 'querystring',
          locationName: 'delimiter'
        }
      }
    };

    const itc = _AwsParam.AwsParam.convertInputStructure(param, 'AwsS3Bucket');

    expect(itc).toBeInstanceOf(_graphqlCompose.InputTypeComposer);
    expect(itc.getTypeName()).toBe('AwsS3BucketInput');
    expect(itc.getFieldType('Bucket')).toBeInstanceOf(_graphql.GraphQLNonNull);
    expect(itc.getFieldType('Bucket').ofType).toBe(_graphql.GraphQLString);
    expect(itc.getFieldType('Delimiter')).toBe(_graphql.GraphQLString);
  });
  it('static convertOutputStructure()', () => {
    const param = {
      type: 'structure',
      required: ['Bucket'],
      members: {
        Bucket: {
          location: 'uri',
          locationName: 'Bucket'
        },
        Delimiter: {
          location: 'querystring',
          locationName: 'delimiter'
        }
      }
    };

    const tc = _AwsParam.AwsParam.convertOutputStructure(param, 'AwsS3Bucket');

    expect(tc).toBeInstanceOf(_graphqlCompose.ObjectTypeComposer);
    expect(tc.getTypeName()).toBe('AwsS3Bucket');
    expect(tc.getFieldType('Bucket')).toBeInstanceOf(_graphql.GraphQLNonNull);
    expect(tc.getFieldType('Bucket').ofType).toBe(_graphql.GraphQLString);
    expect(tc.getFieldType('Delimiter')).toBe(_graphql.GraphQLString);
  });
});

==> graphql-compose-aws-4.0.1.tgz: package/lib/__tests__/AwsParam-test.js <==
"use strict";

var _graphqlCompose = require("graphql-compose");

var _AwsParam = require("../AwsParam");

describe('AwsParam', () => {
  describe('static convertParam()', () => {
    it('scalars', () => {
      expect(_AwsParam.AwsParam.convertParam({
        type: 'boolean'
      }, '')).toBe('Boolean');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'string'
      }, '')).toBe('String');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'integer'
      }, '')).toBe('Int');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'float'
      }, '')).toBe('Float');
      expect(_AwsParam.AwsParam.convertParam({
        type: 'timestamp'
      }, '')).toBe('Date');
      expect(_AwsParam.AwsParam.convertParam({}, '')).toBe('String');
    });
    it('map', () => {
      // it does not have keys, so should be JSON type
      expect(_AwsParam.AwsParam.convertParam({
        type: 'map',
        key: {},
        value: {}
      }, '')).toBe('JSON');
    });
    it('list', () => {
      const t = _AwsParam.AwsParam.convertParam({
        type: 'list',
        member: {},
        flattened: true
      }, '');

      expect(t).toEqual(['String']); // nested lists

      const t2 = _AwsParam.AwsParam.convertParam({
        type: 'list',
        member: {
          type: 'list',
          member: {}
        },
        flattened: true
      }, '');

      expect(t2).toEqual([['String']]);
    });
    it('structure', () => {
      const param = {
        type: 'structure',
        members: {
          Bucket: {}
        }
      };

      const t = _AwsParam.AwsParam.convertParam(param, 'Name');

      expect(t).toBeInstanceOf(_graphqlCompose.ObjectTypeComposer);

      const t2 = _AwsParam.AwsParam.convertParam(param, 'Name', true);

      expect(t2).toBeInstanceOf(_graphqlCompose.InputTypeComposer);
    });
    it('shape', () => {
      const shapesMock = {
        getInputShape: () => 'Int',
        getOutputShape: () => 'String'
      };

      const t = _AwsParam.AwsParam.convertParam({
        shape: 'Sk'
      }, 'Name', true, shapesMock);

      expect(t).toBe('Int');

      const t2 = _AwsParam.AwsParam.convertParam({
        shape: 'Sk'
      }, 'Name', false, shapesMock);

      expect(t2).toBe('String'); // as fallback use JSON, if shapes are empty

      const t3 = _AwsParam.AwsParam.convertParam({
        shape: 'Sk'
      }, 'Name');

      expect(t3).toBe('JSON');
    });
  });
  it('static convertInputStructure()', () => {
    const param = {
      type: 'structure',
      required: ['Bucket'],
      members: {
        Bucket: {
          location: 'uri',
          locationName: 'Bucket'
        },
        Delimiter: {
          location: 'querystring',
          locationName: 'delimiter'
        }
      }
    };

    const itc = _AwsParam.AwsParam.convertInputStructure(param, 'AwsS3Bucket');

    expect(itc).toBeInstanceOf(_graphqlCompose.InputTypeComposer);
    expect(itc.getTypeName()).toBe('AwsS3BucketInput');
    expect(itc.getFieldTypeName('Bucket')).toBe('String!');
    expect(itc.getFieldTypeName('Delimiter')).toBe('String');
  });
  it('static convertOutputStructure()', () => {
    const param = {
      type: 'structure',
      required: ['Bucket'],
      members: {
        Bucket: {
          location: 'uri',
          locationName: 'Bucket'
        },
        Delimiter: {
          location: 'querystring',
          locationName: 'delimiter'
        }
      }
    };

    const tc = _AwsParam.AwsParam.convertOutputStructure(param, 'AwsS3Bucket');

    expect(tc).toBeInstanceOf(_graphqlCompose.ObjectTypeComposer);
    expect(tc.getTypeName()).toBe('AwsS3Bucket');
    expect(tc.getFieldTypeName('Bucket')).toBe('String!');
    expect(tc.getFieldTypeName('Delimiter')).toBe('String');
  });
});
